@@ -1,14 +1,6 @@
-
-__version__ = "1.0.1"
+__version__ = "1.0.3"
 
 from spotify_uri.parse import parse as _parse
-from spotify_uri.search import Search as _Search
-from spotify_uri.local import Local as _Local
-from spotify_uri.playlist import Playlist as _Playlist
-from spotify_uri.artist import Artist as _Artist
-from spotify_uri.album import Album as _Album
-from spotify_uri.track import Track as _Track
-from spotify_uri.user import User as _User
 from spotify_uri.spotify import SpotifyUri
 
 
