@@ -1,3 +1,4 @@
+from typing import Any
 from spotify_uri.spotify import SpotifyUri
 from spotify_uri.util import encode
 
@@ -8,6 +9,14 @@ class Search(SpotifyUri):
         self.query = query
         super(Search, self).__init__(uri)
 
+    @staticmethod
+    def is_(v: Any) -> bool:
+        x = v is Search
+        if x:
+            return v.type == "search"
+        else:
+            return False
+
     def toURI(self) -> str:
         return f"spotify:search:{encode(self.query)}"
 
