@@ -1,9 +1,10 @@
+from typing import Any
 from abc import ABC, abstractmethod
 
 
 class SpotifyUri(ABC):
-    def __init__(self, uri: str):
-        self.uri = uri
+    def __init__(self, uri: str) -> None:
+        self.uri: str = uri
 
     @abstractmethod
     def toURL(self) -> str:
@@ -13,6 +14,14 @@ class SpotifyUri(ABC):
     def toURI(self) -> str:
         pass
 
+    @staticmethod
+    def is_(v: Any) -> bool:
+        x = v is SpotifyUri
+        if x:
+            return type(v.uri) == str
+        else:
+            return False
+
     def toEmbedURL(self) -> str:
         embed_url = f"https://embed.spotify.com/?uri={self.toURI()}"
         return embed_url
